@@ -32,10 +32,15 @@ Usage
 
     from opentelemetry import trace
     from opentelemetry.exporter.jaeger.thrift import JaegerExporter
+    from opentelemetry.sdk.resources import SERVICE_NAME, Resource
     from opentelemetry.sdk.trace import TracerProvider
     from opentelemetry.sdk.trace.export import BatchSpanProcessor
 
-    trace.set_tracer_provider(TracerProvider())
+    trace.set_tracer_provider(
+    TracerProvider(
+            resource=Resource.create({SERVICE_NAME: "my-helloworld-service"})
+        )
+    )
     tracer = trace.get_tracer(__name__)
 
     # create a JaegerExporter
